@@ -7,6 +7,7 @@ use super::face_thumbnails::{FaceThumbnails, FaceThumbnailsInput};
 ///Inspired by how Loupe displays its property view.
 use fotema_core::VisualId;
 use fotema_core::people;
+use fotema_core::FlatpakPathBuf;
 
 use gtk::prelude::OrientableExt;
 
@@ -18,13 +19,12 @@ use relm4::gtk;
 use relm4::gtk::gio;
 use relm4::prelude::*;
 use std::fs;
-use std::path::PathBuf;
 use std::sync::Arc;
 
 use crate::app::SharedState;
 use crate::fl;
 
-use tracing::{Level, event};
+use tracing::{debug, warn};
 
 #[derive(Debug)]
 pub enum ViewInfoInput {
@@ -46,7 +46,8 @@ pub enum ViewInfoInput {
 pub struct ViewInfo {
     state: SharedState,
 
-    path: Option<PathBuf>,
+    path: Option<FlatpakPathBuf>,
+
     folder: adw::ActionRow,
     file_name: adw::ActionRow,
 
@@ -357,9 +358,14 @@ impl SimpleComponent for ViewInfo {
     fn update(&mut self, msg: Self::Input, _sender: ComponentSender<Self>) {
         match msg {
             ViewInfoInput::OpenFolder => {
-                let Some(ref path) = self.path else {
+                // FIXME using self.host_path works when run in GNOME Builder, but
+                // doesn't work in the Flatpak sandbox.
+                let Some(ref path) = self.path.as_ref().map(|p| &p.sandbox_path) else {
                     return;
                 };
+
+                debug!("Trying to open folder for {}", path.to_string_lossy());
+
                 let file = gtk::gio::File::for_path(path);
                 let launcher = gtk::FileLauncher::new(Some(&file));
                 launcher.open_containing_folder(
@@ -375,7 +381,7 @@ impl SimpleComponent for ViewInfo {
                 };
 
                 let Some(ref vis) = result else {
-                    event!(Level::WARN, "No visual item");
+                    warn!("No visual item");
                     return;
                 };
 
@@ -392,7 +398,7 @@ impl SimpleComponent for ViewInfo {
                 };
 
                 let Some(ref vis) = result else {
-                    event!(Level::WARN, "No visual item");
+                    warn!("No visual item");
                     return;
                 };
 
@@ -417,7 +423,7 @@ impl SimpleComponent for ViewInfo {
                 };
 
                 let Some(ref vis) = result else {
-                    event!(Level::WARN, "No visual item");
+                    warn!("No visual item");
                     return;
                 };
 
@@ -442,19 +448,17 @@ const FALLBACK: &str = "–";
 
 impl ViewInfo {
     fn update_file_details(&mut self, vis: Arc<fotema_core::visual::Visual>) -> Result<(), String> {
-        let Some(ref path) = vis.path() else {
-            return Err("No picture or video path".to_string());
-        };
+
+        self.path = Some(vis.path().clone());
 
         Self::update_row(&self.folder, vis.folder_name());
         Self::update_row(
             &self.file_name,
-            path.file_name().map(|x| x.to_string_lossy().to_string()),
+            vis.host_path().file_name().map(|p| p.to_string_lossy()),
         );
-        self.path = Some(path.to_path_buf());
 
         // FIXME duplicated from Scanner
-        let file = fs::File::open(path).map_err(|e| e.to_string())?;
+        let file = fs::File::open(vis.sandbox_path()).map_err(|e| e.to_string())?;
 
         let metadata = file.metadata().map_err(|e| e.to_string())?;
 
@@ -492,7 +496,7 @@ impl ViewInfo {
         };
 
         // FIXME duplicated from Scanner
-        let file = fs::File::open(picture_path).map_err(|e| e.to_string())?;
+        let file = fs::File::open(&picture_path.sandbox_path).map_err(|e| e.to_string())?;
         let metadata = file.metadata().map_err(|e| e.to_string())?;
 
         let fs_file_size_bytes = metadata.len();
@@ -549,10 +553,10 @@ impl ViewInfo {
         };
 
         // FIXME duplicated from Scanner
-        let file = fs::File::open(video_path).map_err(|e| e.to_string())?;
+        let file = fs::File::open(&video_path.sandbox_path).map_err(|e| e.to_string())?;
         let fs_file_size_bytes = file.metadata().ok().map(|x| format_size(x.len(), DECIMAL));
 
-        let metadata = fotema_core::video::metadata::from_path(video_path).ok();
+        let metadata = fotema_core::video::metadata::from_path(&video_path.sandbox_path).ok();
         if metadata.is_none() {
             self.video_details.set_visible(false);
         }
